/**
 * Copyright (c) 2006-2012
 * Software Technology Group, Dresden University of Technology
 * DevBoost GmbH, Berlin, Amtsgericht Charlottenburg, HRB 140026
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Software Technology Group - TU Dresden, Germany;
 *   DevBoost GmbH - Berlin, Germany
 *      - initial API and implementation
 *  
 */
package org.emftext.language.java.generics;

import org.eclipse.emf.common.util.EList;

import org.emftext.language.java.classifiers.Classifier;
import org.emftext.language.java.classifiers.ConcreteClassifier;

import org.emftext.language.java.commons.Commentable;

import org.emftext.language.java.members.Member;

import org.emftext.language.java.references.Reference;

import org.emftext.language.java.types.Type;
import org.emftext.language.java.types.TypeReference;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Type Parameter</b></em>'.
 * <!-- end-user-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.emftext.language.java.generics.TypeParameter#getExtendTypes <em>Extend Types</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.emftext.language.java.generics.GenericsPackage#getTypeParameter()
 * @model
 * @generated
 */
public interface TypeParameter extends Classifier
{
  /**
   * Returns the value of the '<em><b>Extend Types</b></em>' containment reference list.
   * The list contents are of type {@link org.emftext.language.java.types.TypeReference}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Extend Types</em>' containment reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Extend Types</em>' containment reference list.
   * @see org.emftext.language.java.generics.GenericsPackage#getTypeParameter_ExtendTypes()
   * @model containment="true" resolveProxies="true"
   * @generated
   */
  EList<TypeReference> getExtendTypes();

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * 
   *  @return all type restrictions
   * 
   * <!-- end-model-doc -->
   * @model kind="operation"
   *        annotation="http://www.eclipse.org/emf/2002/GenModel body='org.eclipse.emf.common.util.EList< org.emftext.language.java.classifiers.ConcreteClassifier> result = new org.emftext.language.java.util.UniqueEList< org.emftext.language.java.classifiers.ConcreteClassifier>();\nfor( org.emftext.language.java.types.TypeReference typeRef : getExtendTypes()) {\n\torg.emftext.language.java.types.Type type = typeRef.getTarget();\n\tif (type instanceof org.emftext.language.java.classifiers.ConcreteClassifier) {\n\t\tresult.add(( org.emftext.language.java.classifiers.ConcreteClassifier)type);\n\t}\n\tif (type instanceof org.emftext.language.java.classifiers.Classifier) {\n\t\tresult.addAll((( org.emftext.language.java.classifiers.Classifier)type).getAllSuperClassifiers());\t\n\t}\n}\t\t\n\nreturn result;'"
   * @generated
   */
  EList<ConcreteClassifier> getAllSuperClassifiers();

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * 
   *  Returns all members of the given classifier including inner classes and 
   *  all members of super types (extended classes and implemented interfaces).
   *  
   *  @param context to check protected visibility
   *  @return member list
   * 
   * <!-- end-model-doc -->
   * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='org.eclipse.emf.common.util.EList< org.emftext.language.java.members.Member> memberList = new org.emftext.language.java.util.UniqueEList< org.emftext.language.java.members.Member>();\n\norg.emftext.language.java.util.UniqueEList< org.emftext.language.java.types.Type> possiblyVisibleSuperClassifier = new org.emftext.language.java.util.UniqueEList< org.emftext.language.java.types.Type>();\nfor( org.emftext.language.java.types.TypeReference typeReference : (( org.emftext.language.java.generics.TypeParameter)this).getExtendTypes()) {\n\tpossiblyVisibleSuperClassifier.add(typeReference.getTarget());\n}\n\nfor ( org.emftext.language.java.classifiers.ConcreteClassifier superClassifier : getAllSuperClassifiers()) {\n\tfor( org.emftext.language.java.members.Member member : superClassifier.getMembers()) {\n\t\tif(member instanceof org.emftext.language.java.modifiers.AnnotableAndModifiable) {\t\t\t\t\t\n\t\t\torg.emftext.language.java.modifiers.AnnotableAndModifiable modifiable = ( org.emftext.language.java.modifiers.AnnotableAndModifiable) member;\n\n\t\t\tif(!modifiable.isHidden(context)) {\n\t\t\t\tmemberList.add(member);\n\t\t\t}\n\t\t\telse if (possiblyVisibleSuperClassifier.contains(superClassifier)) {\n\t\t\t\tmemberList.add(member);\n\t\t\t}\n\t\t}\n\t\telse {\n\t\t\tmemberList.add(member);\n\t\t}\n\t}\n\tmemberList.addAll(superClassifier.getDefaultMembers());\n}\nreturn memberList;'"
   * @generated
   */
  EList<Member> getAllMembers(Commentable context);

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * 
   *  Returns the type bound to the given parameter in the context
   *  of the given reference.
   *  
   *  @param typeReference
   *  @param reference
   *  @return bound type or parameter if not bound
   * 
   * <!-- end-model-doc -->
   * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='org.eclipse.emf.common.util.EList< org.emftext.language.java.types.Type> resultList = new org.eclipse.emf.common.util.BasicEList< org.emftext.language.java.types.Type>();\norg.emftext.language.java.generics.TypeParametrizable typeParameterDeclarator = ( org.emftext.language.java.generics.TypeParametrizable) this.eContainer();\norg.emftext.language.java.references.Reference parentReference = null;\norg.eclipse.emf.common.util.EList< org.emftext.language.java.types.Type> prevTypeList = new org.emftext.language.java.util.UniqueEList< org.emftext.language.java.types.Type>();\nif (reference != null && \n\t\treference.getPrevious() instanceof org.emftext.language.java.expressions.NestedExpression) {\n\torg.emftext.language.java.expressions.NestedExpression nestedExpression = ( org.emftext.language.java.expressions.NestedExpression) reference.getPrevious();\n\torg.emftext.language.java.expressions.Expression expression = null;\n\tif (nestedExpression.getExpression() instanceof org.emftext.language.java.references.Reference) {\n\t\texpression = nestedExpression.getExpression();\n\t}\n\telse if (nestedExpression.getExpression() instanceof org.emftext.language.java.expressions.ConditionalExpression) {\n\t\texpression = (( org.emftext.language.java.expressions.ConditionalExpression)nestedExpression.getExpression()).getExpressionIf();\n\t}\n\n\t\n\tif (expression instanceof org.emftext.language.java.references.Reference) {\n\t\torg.emftext.language.java.references.Reference expressionReference = ( org.emftext.language.java.references.Reference) expression;\n\t\t//navigate down references\n\t\twhile(expressionReference.getNext() != null) {\n\t\t\texpressionReference = expressionReference.getNext();\n\t\t}\n\t\tparentReference = expressionReference;\n\t\torg.emftext.language.java.types.Type prevType = nestedExpression.getExpression().getType();\n\t\tif(prevType instanceof org.emftext.language.java.util.TemporalCompositeClassifier) {\n\t\t\tfor( org.eclipse.emf.ecore.EObject aType : (( org.emftext.language.java.util.TemporalCompositeClassifier)prevType).getSuperTypes()) {\n\t\t\t\tprevTypeList.add(( org.emftext.language.java.types.Type)aType);\n\t\t\t}\n\t\t}\n\t\telse {\n\t\t\tprevTypeList.add(prevType);\n\t\t}\n\t}\n\telse if (nestedExpression.getExpression() instanceof org.emftext.language.java.expressions.CastExpression) {\n\t\tprevTypeList.add((( org.emftext.language.java.expressions.CastExpression)nestedExpression.getExpression()).getTypeReference().getTarget());\n\t}\n}\nelse if (reference != null && reference.getPrevious() != null) {\n\tparentReference = reference.getPrevious();\n\twhile (parentReference instanceof org.emftext.language.java.references.SelfReference) {\n\t\tif ((( org.emftext.language.java.references.SelfReference)parentReference).getSelf() instanceof org.emftext.language.java.literals.Super) {\n\t\t\tif (parentReference.eContainer() instanceof org.emftext.language.java.references.Reference) {\n\t\t\t\tparentReference = ( org.emftext.language.java.references.Reference) parentReference.eContainer();\n\t\t\t}\n\t\t\telse {\n\t\t\t\torg.emftext.language.java.classifiers.ConcreteClassifier containingClassifier = reference.getContainingConcreteClassifier();\n\t\t\t\tif (containingClassifier != null) {\n\t\t\t\t\tprevTypeList.add(containingClassifier);\n\t\t\t\t}\n\t\t\t\tparentReference = null;\n\t\t\t}\n\t\t}\n\t\telse {\n\t\t\tbreak;\n\t\t}\n\t}\n\tif (parentReference != null) {\n\t\torg.emftext.language.java.types.Type prevType = parentReference.getReferencedType();\n\t\tif(prevType instanceof org.emftext.language.java.util.TemporalCompositeClassifier) {\n\t\t\tfor( org.eclipse.emf.ecore.EObject aType : (( org.emftext.language.java.util.TemporalCompositeClassifier)prevType).getSuperTypes()) {\n\t\t\t\tprevTypeList.add(( org.emftext.language.java.types.Type)aType);\n\t\t\t}\n\t\t}\n\t\telse {\n\t\t\tprevTypeList.add(prevType);\n\t\t}\n\t}\n}\nelse if (reference != null) {\n\t//prev type is on of the containing classes which can still bind by inheritance\n\torg.emftext.language.java.classifiers.ConcreteClassifier containingClassifier = reference.getContainingConcreteClassifier();\n\twhile (containingClassifier != null) {\n\t\tprevTypeList.add(containingClassifier);\n\t\torg.eclipse.emf.ecore.EObject container = containingClassifier.eContainer();\n\t\tif (container instanceof org.emftext.language.java.commons.Commentable) {\n\t\t\tcontainingClassifier = (( org.emftext.language.java.commons.Commentable) container).getContainingConcreteClassifier();\n\t\t} else {\n\t\t\tcontainingClassifier = null;\n\t\t}\n\t}\n}\n\nfor( org.emftext.language.java.types.Type prevType : prevTypeList) {\n\tint typeParameterIndex = -1;\n\tif (typeParameterDeclarator instanceof org.emftext.language.java.classifiers.ConcreteClassifier) {\n\t\ttypeParameterIndex = typeParameterDeclarator.getTypeParameters().indexOf(this);\n\t\tif(reference != null) {\n\t\t\torg.emftext.language.java.types.ClassifierReference classifierReference = null;\n\t\t\tif(parentReference instanceof org.emftext.language.java.references.ElementReference) {\n\t\t\t\torg.emftext.language.java.references.ReferenceableElement prevReferenced = (( org.emftext.language.java.references.ElementReference) parentReference).getTarget();\n\t\t\t\tif(prevReferenced instanceof org.emftext.language.java.types.TypedElement) {\n\t\t\t\t\torg.emftext.language.java.types.TypeReference prevTypeReference = (( org.emftext.language.java.types.TypedElement)prevReferenced).getTypeReference ();\n\t\t\t\t\tif (prevTypeReference != null) {\n\t\t\t\t\t\tclassifierReference = prevTypeReference.getPureClassifierReference(); \n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t}\n\t\t\tif(parentReference instanceof org.emftext.language.java.types.TypedElement) {\n\t\t\t\t//e.g. New Constructor Call\n\t\t\t\torg.emftext.language.java.types.TypeReference prevParentReference = (( org.emftext.language.java.types.TypedElement)parentReference).getTypeReference ();\n\t\t\t\tif (prevParentReference != null) {\n\t\t\t\t\tclassifierReference = prevParentReference.getPureClassifierReference(); \n\t\t\t\t}\n\t\t\t}\n\t\t\tif (prevType instanceof org.emftext.language.java.classifiers.ConcreteClassifier) {\n\t\t\t\t//bound through inheritance?\n\t\t\t\tint idx = 0;\n\t\t\t\tfor( org.emftext.language.java.types.ClassifierReference superClassifierReference : (( org.emftext.language.java.classifiers.ConcreteClassifier) prevType).getSuperTypeReferences()) {\n\t\t\t\t\tif (typeParameterIndex < superClassifierReference.getTypeArguments().size())  {\n\t\t\t\t\t\t//is this an argument for the correct class?\n\t\t\t\t\t\tif (typeParameterDeclarator.equals(superClassifierReference.getTarget()) ||\n\t\t\t\t\t\t\t\t(( org.emftext.language.java.classifiers.Classifier)superClassifierReference.getTarget()).getAllSuperClassifiers().contains(\n\t\t\t\t\t\t\t\t\t\ttypeParameterDeclarator)) {\t\t\t\t\t \n\t\t\t\t\t\t\torg.emftext.language.java.generics.TypeArgument arg = superClassifierReference.getTypeArguments().get(typeParameterIndex);\n\t\t\t\t\t\t\tif (arg instanceof org.emftext.language.java.generics.QualifiedTypeArgument) {\n\t\t\t\t\t\t\t\tresultList.add(idx, (( org.emftext.language.java.generics.QualifiedTypeArgument) arg).getTypeReference().getTarget());\n\t\t\t\t\t\t\t\tidx++;\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t}\n\t\n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t\torg.eclipse.emf.common.util.EList< org.emftext.language.java.generics.TypeArgument> typeArgumentList;\n\t\t\t\torg.emftext.language.java.util.TemporalTypeArgumentHolder ttah = null;\n\t\t\t\tfor( org.eclipse.emf.common.notify.Adapter adapter : prevType.eAdapters()) {\n\t\t\t\t\tif (adapter instanceof org.emftext.language.java.util.TemporalTypeArgumentHolder) {\n\t\t\t\t\t\tttah = ( org.emftext.language.java.util.TemporalTypeArgumentHolder) adapter; \n\t\t\t\t\t\tprevType.eAdapters().remove(ttah);\n\t\t\t\t\t\tbreak;\n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t\tif (ttah != null) {\n\t\t\t\t\ttypeArgumentList = ttah.getTypeArguments();\n\t\t\t\t}\n\t\t\t\telse if (classifierReference != null) {\n\t\t\t\t\ttypeArgumentList = classifierReference.getTypeArguments();\n\t\t\t\t}\n\t\t\t\telse {\n\t\t\t\t\ttypeArgumentList = org.eclipse.emf.common.util.ECollections.emptyEList();\n\t\t\t\t}\n\t\t\t\t\n\t\t\t\tif (typeParameterIndex < typeArgumentList.size())  {\n\t\t\t\t\torg.emftext.language.java.generics.TypeArgument arg = typeArgumentList.get(typeParameterIndex);\n\t\t\t\t\tif (arg instanceof org.emftext.language.java.generics.QualifiedTypeArgument) {\n\t\t\t\t\t\torg.emftext.language.java.types.ClassifierReference theTypeRef = (( org.emftext.language.java.generics.QualifiedTypeArgument) arg).getTypeReference().getPureClassifierReference();\n\t\t\t\t\t\tif (theTypeRef != null) {\n\t\t\t\t\t\t\torg.emftext.language.java.types.Type theType = theTypeRef.getBoundTarget(parentReference);\n\t\t\t\t\t\t\tif (theType != null) {\n\t\t\t\t\t\t\t\tif (!theTypeRef.getTypeArguments().isEmpty()) {\n\t\t\t\t\t\t\t\t\tttah = new org.emftext.language.java.util.TemporalTypeArgumentHolder();\n\t\t\t\t\t\t\t\t\tttah.getTypeArguments().addAll(theTypeRef.getTypeArguments());\n\t\t\t\t\t\t\t\t\ttheType.eAdapters().add(ttah);\n\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\tresultList.add(0, theType);\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\t\t\t\t\tif (arg instanceof org.emftext.language.java.generics.ExtendsTypeArgument) {\n\t\t\t\t\t\tfor( org.emftext.language.java.types.TypeReference extendedType : (( org.emftext.language.java.generics.ExtendsTypeArgument) arg).getExtendTypes()) {\n\t\t\t\t\t\t\tresultList.add(0, extendedType.getBoundTarget(parentReference));\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\t\t\t\t}\n\t\n\t\t\t}\n\t\t\telse if (prevType instanceof org.emftext.language.java.generics.TypeParameter) {\n\t\t\t\t//the prev. type parameter, although unbound, may contain type restrictions through extends \n\t\t\t\tresultList.add(prevType);\n\t\t\t\tfor( org.emftext.language.java.types.TypeReference extendedRef : (( org.emftext.language.java.generics.TypeParameter) prevType).getExtendTypes()) {\n\t\t\t\t\torg.emftext.language.java.classifiers.ConcreteClassifier extended = ( org.emftext.language.java.classifiers.ConcreteClassifier)extendedRef.getTarget();\n\t\t\t\t\tint idx = (( org.emftext.language.java.generics.TypeParametrizable)prevType.eContainer()).getTypeParameters().indexOf(prevType);\n\t\t\t\t\tif (extended.getTypeParameters().size() > idx) {\n\t\t\t\t\t\t//also add more precise bindings from extensions\n\t\t\t\t\t\tresultList.add(extended.getTypeParameters().get(idx));\n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\t\tif(reference != null && reference.eContainer() instanceof org.emftext.language.java.references.ReflectiveClassReference) {\n\t\t\tif (reference.eContainer().eContainer() instanceof org.emftext.language.java.references.Reference) {\n\t\t\t\t//the \".class\" instantiation implicitly binds the T parameter of java.lang.Class to the class itself\n\t\t\t\tresultList.add(0, (( org.emftext.language.java.references.Reference)reference.eContainer().eContainer()).getReferencedType());\n\t\t\t}\n\t\t}\n\t}\n}\n\nif (typeParameterDeclarator instanceof org.emftext.language.java.members.Method) {\n\tif (reference instanceof org.emftext.language.java.references.MethodCall) {\n\t\torg.emftext.language.java.members.Method method = ( org.emftext.language.java.members.Method) typeParameterDeclarator;\n\t\torg.emftext.language.java.references.MethodCall methodCall = ( org.emftext.language.java.references.MethodCall) reference;\n\t\tif(method.getTypeParameters().size() == methodCall.getCallTypeArguments().size()) {\n\t\t\torg.emftext.language.java.generics.TypeArgument typeArgument = methodCall.getCallTypeArguments().get(method.getTypeParameters().indexOf(this));\n\t\t\tif (typeArgument instanceof org.emftext.language.java.generics.QualifiedTypeArgument) {\n\t\t\t\tresultList.add(0, (( org.emftext.language.java.generics.QualifiedTypeArgument)typeArgument).getTypeReference().getBoundTarget(parentReference)); \n\t\t\t} \n\t\t}\n\n\t\t//class type parameter\n\t\tint idx = method.getParameters().indexOf(typeReference.eContainer());\n\t\t\n\t\t//method type parameter\n\t\tif (idx == -1) {\n\t\t\tfor( org.emftext.language.java.parameters.Parameter parameter : method.getParameters()) {\n\t\t\t\tfor ( org.emftext.language.java.generics.TypeArgument typeArgument : parameter.getTypeArguments()) {\n\t\t\t\t\tif(typeArgument instanceof org.emftext.language.java.generics.QualifiedTypeArgument) {\n\t\t\t\t\t\tif((( org.emftext.language.java.generics.QualifiedTypeArgument) typeArgument).getTypeReference().getTarget().equals(this)) {\n\t\t\t\t\t\t\tidx = method.getParameters().indexOf(parameter);\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t\torg.emftext.language.java.types.ClassifierReference paramTypeReference = parameter.getTypeReference().getPureClassifierReference();\n\t\t\t\tif (paramTypeReference != null) {\n\t\t\t\t\tfor ( org.emftext.language.java.generics.TypeArgument typeArgument : paramTypeReference.getTypeArguments()) {\n\t\t\t\t\t\tif(typeArgument instanceof org.emftext.language.java.generics.QualifiedTypeArgument) {\n\t\t\t\t\t\t\tif(this.equals((( org.emftext.language.java.generics.QualifiedTypeArgument) typeArgument).getTypeReference().getTarget())) {\n\t\t\t\t\t\t\t\tidx = method.getParameters().indexOf(parameter);\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\t\t\n\t\tif (idx < methodCall.getArguments().size() && idx >= 0) {\n\t\t\torg.emftext.language.java.expressions.Expression argument = methodCall.getArguments().get(idx);\n\t\t\torg.emftext.language.java.parameters.Parameter parameter = method.getParameters().get(idx);\n\t\t\torg.emftext.language.java.types.ClassifierReference parameterType = parameter.getTypeReference().getPureClassifierReference();\n\t\t\tif (argument instanceof org.emftext.language.java.instantiations.NewConstructorCall) {\n\t\t\t\torg.emftext.language.java.types.ClassifierReference argumentType = (( org.emftext.language.java.instantiations.NewConstructorCall)argument).getTypeReference().getPureClassifierReference();\n\t\t\t\tif (argumentType != null && parameterType.getTypeArguments().size() == argumentType.getTypeArguments().size()) {\n\t\t\t\t\tfor( org.emftext.language.java.generics.TypeArgument typeArgument : parameterType.getTypeArguments()) {\n\t\t\t\t\t\tif(typeArgument instanceof org.emftext.language.java.generics.QualifiedTypeArgument) {\n\t\t\t\t\t\t\tif((( org.emftext.language.java.generics.QualifiedTypeArgument) typeArgument).getTypeReference().getTarget().equals(this)) {\n\t\t\t\t\t\t\t\tresultList.add(0, (( org.emftext.language.java.generics.QualifiedTypeArgument)argumentType.getTypeArguments().get(parameterType.getTypeArguments().indexOf(typeArgument))).getTypeReference(\n\t\t\t\t\t\t\t\t\t).getTarget());\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t\tif (argumentType != null && parameterType.getTarget() instanceof org.emftext.language.java.generics.TypeParameter) {\n\t\t\t\t\tresultList.add(0,argumentType.getTarget());\n\t\t\t\t}\n\t\t\t}\n\t\t\telse if (parameterType != null && argument instanceof org.emftext.language.java.references.Reference) {\n\t\t\t\torg.emftext.language.java.references.Reference argReference = ( org.emftext.language.java.references.Reference) argument;\n\t\t\t\t\n\t\t\t\twhile (argReference.getNext() instanceof org.emftext.language.java.references.Reference &&\n\t\t\t\t\t\t!(argReference.getNext() instanceof org.emftext.language.java.references.ReflectiveClassReference) ) {\n\t\t\t\t\targReference = argReference.getNext();\n\t\t\t\t}\n\t\n\t\t\t\t\n\t\t\t\tif (argReference instanceof org.emftext.language.java.references.ElementReference) {\n\t\t\t\t\torg.emftext.language.java.references.ElementReference elementReference = ( org.emftext.language.java.references.ElementReference) argReference;\n\t\t\t\t\twhile (elementReference.getNext() instanceof org.emftext.language.java.references.ElementReference) {\n\t\t\t\t\t\telementReference = ( org.emftext.language.java.references.ElementReference) elementReference.getNext();\n\t\t\t\t\t}\n\t\t\t\t\tif (elementReference.getTarget() instanceof org.emftext.language.java.types.TypedElement) {\n\t\t\t\t\t\torg.emftext.language.java.types.ClassifierReference argumentType = (( org.emftext.language.java.types.TypedElement)elementReference.getTarget()).getTypeReference().getPureClassifierReference();\n\t\t\t\t\t\tif (argumentType != null && parameterType.getTypeArguments().size() == argumentType.getTypeArguments().size()) {\n\t\t\t\t\t\t\tfor( org.emftext.language.java.generics.TypeArgument typeArgument : parameterType.getTypeArguments()) {\n\t\t\t\t\t\t\t\tif(typeArgument instanceof org.emftext.language.java.generics.QualifiedTypeArgument) {\n\t\t\t\t\t\t\t\t\tif((( org.emftext.language.java.generics.QualifiedTypeArgument) typeArgument).getTypeReference().getTarget().equals(this)) {\n\t\t\t\t\t\t\t\t\t\tint idx2 = parameterType.getTypeArguments().indexOf(typeArgument);\n\t\t\t\t\t\t\t\t\t\tif (argumentType.getTypeArguments().get(idx2) instanceof org.emftext.language.java.generics.QualifiedTypeArgument) {\n\t\t\t\t\t\t\t\t\t\t\tresultList.add(0, (( org.emftext.language.java.generics.QualifiedTypeArgument)argumentType.getTypeArguments().get(idx2)).getTypeReference().getTarget());\n\t\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\t\telse if (argumentType.getTypeArguments().get(idx2) instanceof org.emftext.language.java.generics.ExtendsTypeArgument) {\n\t\t\t\t\t\t\t\t\t\t\tfor( org.emftext.language.java.types.TypeReference extendedType : (( org.emftext.language.java.generics.ExtendsTypeArgument) argumentType.getTypeArguments().get(idx2)).getExtendTypes()) {\n\t\t\t\t\t\t\t\t\t\t\t\tresultList.add(0, extendedType.getTarget());\n\t\t\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t}\n\t\t\t\t\t\tif (argumentType != null && parameterType.getTarget() instanceof org.emftext.language.java.generics.TypeParameter) {\n\t\t\t\t\t\t\tresultList.add(0,argumentType.getTarget());\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\t\t\t\t\tif(elementReference.getNext() instanceof org.emftext.language.java.references.ReflectiveClassReference) {\n\t\t\t\t\t\tif (parameterType.getTypeArguments().size() == 1) {\n\t\t\t\t\t\t\tfor( org.emftext.language.java.generics.TypeArgument typeArgument : parameterType.getTypeArguments()) {\n\t\t\t\t\t\t\t\tif(typeArgument instanceof org.emftext.language.java.generics.QualifiedTypeArgument) {\n\t\t\t\t\t\t\t\t\tif((( org.emftext.language.java.generics.QualifiedTypeArgument) typeArgument).getTypeReference().getTarget().equals(this)) {\n\t\t\t\t\t\t\t\t\t\tresultList.add(0, elementReference.getReferencedType());\n\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t\telse {\n\t\t\t\t\tif (parameterType.getTarget() instanceof org.emftext.language.java.generics.TypeParameter) {\n\t\t\t\t\t\twhile (argReference.getNext() instanceof org.emftext.language.java.references.Reference) {\n\t\t\t\t\t\t\targReference = argReference.getNext();\n\t\t\t\t\t\t}\n\t\t\t\t\t\tresultList.add(0, (( org.emftext.language.java.references.Reference) argReference).getReferencedType());\n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t}\t\t\t\n\t\t}\n\t\t\n\t\t//return type\n\t\tif(method.equals(typeReference.eContainer())) {\n\t\t\t//bound by the type of a method argument?\n\t\t\torg.eclipse.emf.common.util.EList< org.emftext.language.java.classifiers.Classifier> allSuperTypes = null;\n\t\t\tfor( org.emftext.language.java.parameters.Parameter parameter : method.getParameters()) {\n\t\t\t\tif(this.equals(parameter.getTypeReference().getTarget())) {\n\t\t\t\t\tidx = method.getParameters().indexOf(parameter);\n\t\t\t\t\torg.emftext.language.java.classifiers.Classifier argumentType = ( org.emftext.language.java.classifiers.Classifier) methodCall.getArguments().get(idx).getType();\n\t\t\t\t\tif(allSuperTypes == null) {\n\t\t\t\t\t\tallSuperTypes = new org.emftext.language.java.util.UniqueEList< org.emftext.language.java.classifiers.Classifier>();\n\t\t\t\t\t\tallSuperTypes.add(argumentType);\n\t\t\t\t\t\tallSuperTypes.addAll(argumentType.getAllSuperClassifiers());\n\t\t\t\t\t}\n\t\t\t\t\telse {\n\t\t\t\t\t\tallSuperTypes.add(argumentType);\n\t\t\t\t\t\torg.eclipse.emf.common.util.EList< org.emftext.language.java.classifiers.Classifier> allOtherSuperTypes = new org.emftext.language.java.util.UniqueEList< org.emftext.language.java.classifiers.Classifier>();\n\t\t\t\t\t\tallOtherSuperTypes.add(argumentType);\n\t\t\t\t\t\tallOtherSuperTypes.addAll(argumentType.getAllSuperClassifiers());\n\t\t\t\t\t\torg.eclipse.emf.common.util.EList< org.emftext.language.java.classifiers.Classifier> temp = allSuperTypes;\n\t\t\t\t\t\tallSuperTypes = new org.emftext.language.java.util.UniqueEList< org.emftext.language.java.classifiers.Classifier>();\n\t\t\t\t\t\tfor( org.emftext.language.java.classifiers.Classifier st : allOtherSuperTypes) {\n\t\t\t\t\t\t\tif(temp.contains(st)) {\n\t\t\t\t\t\t\t\tallSuperTypes.add(st);\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\t\t\t\t}\n\t \t\t\t\t}\n\t\t\t//all types given by all bindings\n\t\t\tif (allSuperTypes != null) {\n\t\t\t\tresultList.addAll(allSuperTypes);\n\t\t\t}\n\t\t}\n\t}\n}\n\n//remove nulls\nfor( java.util.Iterator<?> it = resultList.iterator(); it.hasNext(); ) {\n\tif (it.next() == null) {\n\t\tit.remove();\n\t}\n}\n\nif(resultList.isEmpty() || \n\t\t(resultList.size() == 1 && resultList.get(0).equals(this))) {\n\treturn this;\n}\nelse {\n\torg.emftext.language.java.util.TemporalCompositeClassifier temp = new org.emftext.language.java.util.TemporalCompositeClassifier(this);\n\tfor( org.emftext.language.java.types.Type aResult : resultList) {\n\t\tif(aResult instanceof org.emftext.language.java.types.PrimitiveType) {\n\t\t\taResult = (( org.emftext.language.java.types.PrimitiveType) aResult).wrapPrimitiveType();\n\t\t}\n\t\t\n\t\tif (aResult instanceof org.emftext.language.java.util.TemporalCompositeClassifier) {\n\t\t\t//flatten\n\t\t\ttemp.getSuperTypes().addAll((( org.emftext.language.java.util.TemporalCompositeClassifier)aResult).getSuperTypes());\n\t\t}\n\t\telse {\n\t\t\ttemp.getSuperTypes().add(( org.emftext.language.java.classifiers.Classifier) aResult);\t\n\t\t}\n\t}\n\ttemp.getSuperTypes().add(this);\n\treturn temp;\n}'"
   * @generated
   */
  Type getBoundType(TypeReference typeReference, Reference reference);

} // TypeParameter
