/**
 * Copyright (c) 2006-2012
 * Software Technology Group, Dresden University of Technology
 * DevBoost GmbH, Berlin, Amtsgericht Charlottenburg, HRB 140026
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Software Technology Group - TU Dresden, Germany;
 *   DevBoost GmbH - Berlin, Germany
 *      - initial API and implementation
 *  
 */
package org.emftext.language.java.members.provider;


import java.util.Collection;
import java.util.List;

import org.eclipse.emf.common.notify.AdapterFactory;
import org.eclipse.emf.common.notify.Notification;

import org.eclipse.emf.ecore.EStructuralFeature;

import org.eclipse.emf.edit.provider.IEditingDomainItemProvider;
import org.eclipse.emf.edit.provider.IItemLabelProvider;
import org.eclipse.emf.edit.provider.IItemPropertyDescriptor;
import org.eclipse.emf.edit.provider.IItemPropertySource;
import org.eclipse.emf.edit.provider.IStructuredItemContentProvider;
import org.eclipse.emf.edit.provider.ITreeItemContentProvider;
import org.eclipse.emf.edit.provider.ViewerNotification;

import org.emftext.language.java.arrays.ArraysPackage;

import org.emftext.language.java.classifiers.ClassifiersFactory;

import org.emftext.language.java.members.ClassMethod;
import org.emftext.language.java.members.MembersPackage;

import org.emftext.language.java.statements.StatementsFactory;
import org.emftext.language.java.statements.StatementsPackage;

import org.emftext.language.java.types.TypesPackage;

/**
 * This is the item provider adapter for a {@link org.emftext.language.java.members.ClassMethod} object.
 * <!-- begin-user-doc -->
 * <!-- end-user-doc -->
 * @generated
 */
public class ClassMethodItemProvider
  extends MethodItemProvider
  implements
    IEditingDomainItemProvider,
    IStructuredItemContentProvider,
    ITreeItemContentProvider,
    IItemLabelProvider,
    IItemPropertySource
{
  /**
   * This constructs an instance from a factory and a notifier.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public ClassMethodItemProvider(AdapterFactory adapterFactory)
  {
    super(adapterFactory);
  }

  /**
   * This returns the property descriptors for the adapted class.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public List<IItemPropertyDescriptor> getPropertyDescriptors(Object object)
  {
    if (itemPropertyDescriptors == null)
    {
      super.getPropertyDescriptors(object);

    }
    return itemPropertyDescriptors;
  }

  /**
   * This specifies how to implement {@link #getChildren} and is used to deduce an appropriate feature for an
   * {@link org.eclipse.emf.edit.command.AddCommand}, {@link org.eclipse.emf.edit.command.RemoveCommand} or
   * {@link org.eclipse.emf.edit.command.MoveCommand} in {@link #createCommand}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Collection<? extends EStructuralFeature> getChildrenFeatures(Object object)
  {
    if (childrenFeatures == null)
    {
      super.getChildrenFeatures(object);
      childrenFeatures.add(StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS);
    }
    return childrenFeatures;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  protected EStructuralFeature getChildFeature(Object object, Object child)
  {
    // Check the type of the specified child object and return the proper feature to use for
    // adding (see {@link AddCommand}) it as a child.

    return super.getChildFeature(object, child);
  }

  /**
   * This returns ClassMethod.gif.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Object getImage(Object object)
  {
    return overlayImage(object, getResourceLocator().getImage("full/obj16/ClassMethod"));
  }

  /**
   * This returns the label text for the adapted class.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public String getText(Object object)
  {
    String label = ((ClassMethod)object).getName();
    return label == null || label.length() == 0 ?
      getString("_UI_ClassMethod_type") :
      getString("_UI_ClassMethod_type") + " " + label;
  }

  /**
   * This handles model notifications by calling {@link #updateChildren} to update any cached
   * children and by creating a viewer notification, which it passes to {@link #fireNotifyChanged}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public void notifyChanged(Notification notification)
  {
    updateChildren(notification);

    switch (notification.getFeatureID(ClassMethod.class))
    {
      case MembersPackage.CLASS_METHOD__STATEMENTS:
        fireNotifyChanged(new ViewerNotification(notification, notification.getNotifier(), true, false));
        return;
    }
    super.notifyChanged(notification);
  }

  /**
   * This adds {@link org.eclipse.emf.edit.command.CommandParameter}s describing the children
   * that can be created under this object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  protected void collectNewChildDescriptors(Collection<Object> newChildDescriptors, Object object)
  {
    super.collectNewChildDescriptors(newChildDescriptors, object);

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         ClassifiersFactory.eINSTANCE.createClass()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         ClassifiersFactory.eINSTANCE.createInterface()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         ClassifiersFactory.eINSTANCE.createEnumeration()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         ClassifiersFactory.eINSTANCE.createAnnotation()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createAssert()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createBreak()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createBlock()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createCondition()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createContinue()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createWhileLoop()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createDoWhileLoop()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createEmptyStatement()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createExpressionStatement()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createForLoop()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createForEachLoop()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createJumpLabel()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createLocalVariableStatement()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createReturn()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createSwitch()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createSynchronizedBlock()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createThrow()));

    newChildDescriptors.add
      (createChildParameter
        (StatementsPackage.Literals.STATEMENT_LIST_CONTAINER__STATEMENTS,
         StatementsFactory.eINSTANCE.createTryBlock()));
  }

  /**
   * This returns the label text for {@link org.eclipse.emf.edit.command.CreateChildCommand}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public String getCreateChildText(Object owner, Object feature, Object child, Collection<?> selection)
  {
    Object childFeature = feature;
    Object childObject = child;

    boolean qualify =
      childFeature == TypesPackage.Literals.TYPED_ELEMENT__TYPE_REFERENCE ||
      childFeature == MembersPackage.Literals.EXCEPTION_THROWER__EXCEPTIONS ||
      childFeature == ArraysPackage.Literals.ARRAY_TYPEABLE__ARRAY_DIMENSIONS_BEFORE ||
      childFeature == ArraysPackage.Literals.ARRAY_TYPEABLE__ARRAY_DIMENSIONS_AFTER;

    if (qualify)
    {
      return getString
        ("_UI_CreateChild_text2",
         new Object[] { getTypeText(childObject), getFeatureText(childFeature), getTypeText(owner) });
    }
    return super.getCreateChildText(owner, feature, child, selection);
  }

}
